@@ -88,6 +88,9 @@ class UserModel(BaseModel):
         self.id = doc.save().id
         return self
 
+    def delete(self: ModelT) -> None:
+        UserModelDocument(id=self.id).delete()
+
     @classmethod
     def current(cls) -> ModelT | None:
         from ..context import ctx
