@@ -714,7 +714,7 @@ class GetChatMember(TgMethod):
     chat_id: int | str
     user_id: int
 
-    __response_type__ = ChatMember
+    __response_type__ = ChatMemberT
 
 
 @dataclass
